@@ -530,7 +530,7 @@ parse_error:
 }
 
 SoupXmlrpcMessage*
-bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version,
+bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gnome_version,
 		        const char *username, const char *title, const char *text,
 		        GladeXML *xml, GError **err)
 {
@@ -539,7 +539,6 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 	char *distro;
 	char *comment;
 	char *user_agent;
-	int type;
 
 	g_return_val_if_fail (app != NULL, NULL);
 	g_return_val_if_fail (gnome_version != NULL, NULL);
@@ -596,14 +595,15 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 	soup_xmlrpc_message_write_string (message, username);
 	soup_xmlrpc_message_end_member (message);
 
-	soup_xmlrpc_message_start_member (message, "priority");
-	soup_xmlrpc_message_write_string (message, "High");
-	soup_xmlrpc_message_end_member (message);
-
-	soup_xmlrpc_message_start_member (message, "bug_severity");
-	soup_xmlrpc_message_write_string (message, "critical");
-	soup_xmlrpc_message_end_member (message);
+	if (type == BUG_TYPE_CRASH) {
+		soup_xmlrpc_message_start_member (message, "priority");
+		soup_xmlrpc_message_write_string (message, "High");
+		soup_xmlrpc_message_end_member (message);
 
+		soup_xmlrpc_message_start_member (message, "bug_severity");
+		soup_xmlrpc_message_write_string (message, "critical");
+		soup_xmlrpc_message_end_member (message);
+	}
 
 	soup_xmlrpc_message_start_member (message, "short_desc");
 	soup_xmlrpc_message_write_string (message, title); 
